function integral = NavierStokesContinuity(u, v, w, du, dv, dw, dx, ds, x, d, t, eq)

% Variational formulation of the continuity equation in the Navier-Stokes system.
% (c) Johan Hoffman and Anders Logg 2003.
% Licensed under the GNU GPL Version 2.

d1 = 2*sqrt(dx/pi);

% w(1)  = previous time value of u1: up1
% w(2)  = previous time value of u2: up2
% w(3)  = frozen velocity field U1
% w(4)  = frozen velocity field U2
% w(5)  = pressure p 

if eq == 1
  integral = d1*du'*dv*dx + g(x,d,t)*u*v*ds + 0.1*u*v;
else
  integral = - (dw(1,3)+dw(2,4))*v*dx + (g(x,d,t)*gd(x,d,t) - gn(x,d,t))*v*ds + d1*sdrhs(w,dw,du,dv,x,d,t)*dx;
end

%--- Convection ---
function y = b(w, x, d, t)
y = [w(3); w(4)];

%--- Stabilization for rhs ---
function y = sdrhs(w, dw, du, dv, x, d, t)
y = f(x,d,t)'*dv + [w(3)*dw(1,3) + w(4)*dw(2,3); w(3)*dw(1,4) + w(4)*dw(2,4)]'*dv;  

%--- Conductivity (penalty factor) ---
function y = g(x, d, t)
y = 0;  

%--- Dirichlet boundary condition ----
function y = gd(x, d, t)
y = 0;

%--- Neumann boundary condition ---
function y = gn(x, d, t)
y = 0;

%--- Right-hand side, source term ---
function y = f(x, d, t)
y = [0; 0];

