function integral = NavierStokesMomentum2(u, v, w, du, dv, dw, dx, ds, x, d, t, eq)

% Variational formulation of the second momentum equation in the Navier-Stokes system.
% (c) Johan Hoffman and Anders Logg 2003.
% Licensed under the GNU GPL Version 2.

k = 0.05;

visc = w(6);

d1 = 2*sqrt(dx/pi);

% w(1)  = previous time value of u1: up1
% w(2)  = previous time value of u2: up2
% w(3)  = frozen velocity field U1
% w(4)  = frozen velocity field U2
% w(5)  = pressure p 


if eq == 1
  integral = u*v*dx + k*(visc*du'*dv*dx + b(w,x,d,t)'*du*v*dx + sdlhs(d1,w,du,dv,x,d,t)*dx + g(x,d,t)*u*v*ds);
else
  integral = k*(f(x,d,t)*v*dx + w(5)*dv(2)*dx + (g(x,d,t)*gd(x,d,t) - gn(x,d,t))*v*ds + sdrhs(d1,w,dw,du,dv,x,d,t)*dx) + w(2)*v*dx;
end

%--- Convection ---
function y = b(w, x, d, t)
y = [w(3); w(4)];

%--- Stabilization for lhs ---
function y = sdlhs(d1, w, du, dv, x, d, t)
y = d1*(([w(3); w(4)]'*du) * ([w(3); w(4)]'*dv));  

%--- Stabilization for rhs ---
function y = sdrhs(d1, w, dw, du, dv, x, d, t)
y = d1*(f(x,d,t)*[w(3); w(4)]'*dv - dw(2,5)*[w(3); w(4)]'*dv);  

%--- Conductivity (penalty factor) ---
function y = g(x, d, t)
y = 1e7;  

%--- Dirichlet boundary condition ----
function y = gd(x, d, t)
y = 0;

%--- Neumann boundary condition ---
function y = gn(x, d, t)
y = 0;

%--- Right-hand side, source term ---
function y = f(x, d, t)
y = 0;

