% A simple solver for Navier-Stokes equations (cG(1)dG(0). 
% (c) Johan Hoffman and Anders Logg 2003.
% Licensed under the GNU GPL Version 2.

% Load the mesh
square

T = 3.5;
k = 0.05;
time = 0;

visc = 1/100 * ones(size(p,2),1);

% Initial condition
Uxp = zeros(size(p,2),1);
Uyp = zeros(size(p,2),1);

Ux = zeros(size(p,2),1);
Uy = zeros(size(p,2),1);
P  = zeros(size(p,2),1);

% Coefficients
% w(1)  = previous time value of u1
% w(2)  = previous time value of u2
% w(3)  = frozen velocity field U1
% w(4)  = frozen velocity field U2
% w(5)  = pressure p 

clear M

% Time-stepping
for n = 1:70
     
  time = time + k;
  Uxp = Ux;
  Uyp = Uy;
	
  % Non linear loop 
  %for i=1:3 

  % Assemble matrix
  A1 = AssembleMatrix(p, e, t, 'NavierStokesMomentum1',  [Uxp, Uyp, Ux, Uy, P, visc], time);

  % Assemble vector
  b1 = AssembleVector(p, e, t, 'NavierStokesMomentum1',  [Uxp, Uyp, Ux, Uy, P, visc], time);

  % Solve the linear system
  Ux = A1 \ b1;
   
  % Assemble matrix
  A2 = AssembleMatrix(p, e, t, 'NavierStokesMomentum2',  [Uxp, Uyp, Ux, Uy, P, visc], time);

  % Assemble vector
  b2 = AssembleVector(p, e, t, 'NavierStokesMomentum2',  [Uxp, Uyp, Ux, Uy, P, visc], time);

  % Solve the linear system
  Uy = A2 \ b2;
   
  % Assemble matrix
  A3 = AssembleMatrix(p, e, t, 'NavierStokesContinuity', [Uxp, Uyp, Ux, Uy, P, visc], time);

  % Assemble vector
  b3 = AssembleVector(p, e, t, 'NavierStokesContinuity', [Uxp, Uyp, Ux, Uy, P, visc], time);

  % Solve the linear system
  P  = A3 \ b3;

  %end 
   
  % Plot solution
  %pdesurf(p, t, sqrt((Ux).^2+(Uy).^2))
  %shading interp
  quiver(p(1,:),p(2,:),Ux,Uy)
  view(2)
  %M(n) = getframe;
  drawnow
  disp(['t = ' num2str(time)])
%  disp(['t = ' num2str(time) ' Press any key to continue.'])
%  pause
	
  if time >= T
    break;
  end

end

%movie(M)
